@@ -21,7 +21,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QWidget>
+#include <DWidget>
 #include <QTimer>
 #include <QApplication>
 #include <QPen>
@@ -35,7 +35,7 @@ const int CountdownTooltip::NUMBER_PADDING_Y = 30;
 
 DWIDGET_USE_NAMESPACE
 
-CountdownTooltip::CountdownTooltip(QWidget *parent) : QWidget(parent)
+CountdownTooltip::CountdownTooltip(DWidget *parent) : DWidget(parent)
 {
     installEventFilter(this);
 
@@ -55,8 +55,8 @@ void CountdownTooltip::paintEvent(QPaintEvent *)
 
         qreal devicePixelRatio = qApp->devicePixelRatio();
         painter.setOpacity(1);
-        int countdownX = rect().x() + (rect().width() - countdown1Img.width() / devicePixelRatio) / 2;
-        int countdownY = rect().y() + NUMBER_PADDING_Y * devicePixelRatio;
+        int countdownX = static_cast<int>(rect().x() + (rect().width() - countdown1Img.width() / devicePixelRatio) / 2);
+        int countdownY = static_cast<int>(rect().y() + NUMBER_PADDING_Y * devicePixelRatio);
         if (showCountdownCounter == 1) {
             painter.drawPixmap(QPoint(countdownX, countdownY), countdown1Img);
         } else if (showCountdownCounter == 2) {
