@@ -19,7 +19,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */ 
+ */
+
+#ifndef RECORDPROCESS_H
+#define RECORDPROCESS_H
 
 #include "settings.h"
 #include <QProcess>
@@ -27,39 +30,52 @@
 #include <QRect>
 #include <proc/readproc.h>
 #include <proc/sysinfo.h>
+#include "utils/desktopinfo.h"
 
 class RecordProcess : public QThread
 {
     Q_OBJECT
-    
+
     typedef std::map<int, proc_t> StoredProcType;
-    
+
 public:
     static const int RECORD_TYPE_VIDEO;
     static const int RECORD_TYPE_GIF;
     static const int RECORD_GIF_SLEEP_TIME;
-    
-    RecordProcess(QObject *parent = 0);
-    
+    static const int RECORD_AUDIO_INPUT_MIC;
+    static const int RECORD_AUDIO_INPUT_SYSTEMAUDIO;
+    static const int RECORD_AUDIO_INPUT_MIC_SYSTEMAUDIO;
+
+    static const int RECORD_FRAMERATE_5;
+    static const int RECORD_FRAMERATE_10;
+    static const int RECORD_FRAMERATE_20;
+    static const int RECORD_FRAMERATE_24;
+    static const int RECORD_FRAMERATE_30;
+
+    RecordProcess(QObject *parent = nullptr);
+
     void setRecordInfo(const QRect &recordRect, const QString &filename);
     void setRecordType(int recordType);
+    void setFrameRate(int framerate);
+    void setRecordAudioInputType(int inputType);
     void startRecord();
+    void setIsZhaoXinPlatform(bool status);
     void stopRecord();
     void recordGIF();
     void recordVideo();
     void initProcess();
     int readSleepProcessPid();
-    
 protected:
     void run();
 
 private:
-    QProcess* process;
+    QProcess *process;
 
     int recordType;
+    int recordAudioInputType;
 
     QRect m_recordRect;
-    
+
     QString savePath;
     QString saveBaseName;
     QString saveTempDir;
@@ -67,9 +83,16 @@ private:
     QString defaultSaveDir;
     QString saveAreaName;
     QString displayNumber;
-    
-    Settings* settings;
-    
+
+    Settings *settings;
+
     int byzanzProcessId;
     int sleepProcessId;
+    int m_framerate;
+
+    QString lastAudioSink;
+    bool m_isZhaoxin = false;
+    DesktopInfo m_info;
 };
+
+#endif //RECORDPROCESS_H
