@@ -2,27 +2,26 @@
 <context>
     <name>CountdownTooltip</name>
     <message>
-        <location filename="../src/countdown_tooltip.cpp" line="73"/>
-        <source>Click tray icon 
+        <location filename="../src/countdown_tooltip.cpp" line="78"/>
+        <source>Click the tray icon 
 or press the shortcut again to stop recording</source>
-        <translation>Щракнете на системната икона
-или краткият път отново за спиране на записа</translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/main_window.cpp" line="67"/>
+        <location filename="../src/main_window.cpp" line="76"/>
         <source>Deepin screen recorder</source>
         <translation>Deepin запис на екрана</translation>
     </message>
     <message>
-        <location filename="../src/main_window.cpp" line="121"/>
+        <location filename="../src/main_window.cpp" line="136"/>
         <source>Start recording</source>
         <translation>Започни запис</translation>
     </message>
     <message>
-        <location filename="../src/main_window.cpp" line="422"/>
+        <location filename="../src/main_window.cpp" line="454"/>
         <source>Select area</source>
         <translation>Избор на област</translation>
     </message>
@@ -30,22 +29,22 @@ or press the shortcut again to stop recording</source>
 <context>
     <name>RecordProcess</name>
     <message>
-        <location filename="../src/record_process.cpp" line="137"/>
+        <location filename="../src/record_process.cpp" line="229"/>
         <source>deepin-screen-recorder</source>
         <translation>deepin-screen-recorder</translation>
     </message>
     <message>
-        <location filename="../src/record_process.cpp" line="185"/>
+        <location filename="../src/record_process.cpp" line="291"/>
         <source>View</source>
         <translation>Изглед</translation>
     </message>
     <message>
-        <location filename="../src/record_process.cpp" line="195"/>
-        <source>Record finished</source>
-        <translation>Записа приключи</translation>
+        <location filename="../src/record_process.cpp" line="301"/>
+        <source>Recording finished</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/record_process.cpp" line="196"/>
+        <location filename="../src/record_process.cpp" line="302"/>
         <source>Saved to</source>
         <translation>Запазено в</translation>
     </message>
@@ -53,20 +52,11 @@ or press the shortcut again to stop recording</source>
 <context>
     <name>StartTooltip</name>
     <message>
-        <location filename="../src/start_tooltip.cpp" line="45"/>
+        <location filename="../src/start_tooltip.cpp" line="48"/>
         <source>Click or drag to
 select the area to record</source>
         <translation>Щракни или влачи до
 избраната област за запис</translation>
     </message>
 </context>
-<context>
-    <name>WindowManager</name>
-    <message>
-        <location filename="../src/window_manager.cpp" line="150"/>
-        <location filename="../src/window_manager.cpp" line="169"/>
-        <source>Desktop</source>
-        <translation>Десктоп</translation>
-    </message>
-</context>
 </TS>
\ No newline at end of file
